# Fast Variational Block-Sparse Bayesian Learning

This repository contains the matlab implementation of the fast variational block-sparse Bayesian learning algorithm (FV-BSBL) described in [[1](https://doi.org/10.48550/arXiv.2306.00442)].

## Repository Structure

- _fastBSBL:_ Folder containing the algorithm described in [[1](https://doi.org/10.48550/arXiv.2306.00442)]
    - **fastBSBL/fastBSBL.m:** main file of the algorithm
- _BSBL_public:_ Folder containing the comparison algorithms BSBL-EM and BSBL-BO described in [[2](https://doi.org/10.1109/TSP.2013.2241055)], copied from [http://dsp.ucsd.edu/~zhilin/BSBL.html](http://dsp.ucsd.edu/~zhilin/BSBL.html)
- _SBL_MV_matlab:_ Folder containing the DOA-SBL comparison algorithm decsribed in [3], copied from [https://github.com/gerstoft/SBL](https://github.com/gerstoft/SBL)
- **testFastBSBL.m:** Demo script that generates a signal based on a Gaussian dictionary and blocks-sparse weights and applies the algorithms [[1](https://doi.org/10.48550/arXiv.2306.00442)] and [[2](https://doi.org/10.1109/TSP.2013.2241055)].
- **application_DoA.m:** Demo script how to apply the algorithm to Direction-of-Arrival (DOA) estimation and compares the performance to [[3](https://doi.org/10.1109/LSP.2016.2598550)]
- **plotThresholding.m:** Script to generate [[1, Figure 1](https://doi.org/10.48550/arXiv.2306.00442)].
- _ospa_dist.m:_ function to calculate the OSPA distance, needed for application_DoA.m
- _munkres.m:_ auxilary function required for ospa_dist.m


## References

[1] [J. Möderl, F. Pernkopf, K. Witrisal and E. Leitinger, "Fast Variational Block-Sparse Bayesian Learning", arXiv:2306.00442, 2023.](https://arxiv.org/abs/2306.00442)

[2] [Z. Zhang and B. D. Rao, "Extension of SBL algorithms for the recovery of block sparse signals with intra-block correlation," IEEE Trans. Signal Process., vol. 61, no. 8, pp. 2009–2015, Apr. 2013.](https://doi.org/10.1109/TSP.2013.2241055)

[3] [P. Gerstoft, C. F. Mecklenbräuker, A. Xenaki, and S. Nannuru, "Multisnapshot sparse Bayesian learning for DOA,” IEEE Signal Process. Lett., vol. 23, no. 10, pp. 1469–1473, Oct. 2016.](https://doi.org/10.1109/LSP.2016.2598550)